;;; markam -- Store/retrieve/manage bookmarks
;; Copyright (C) 2012, 2013 Tom Willemsen <tom at ryuslash dot org>

;; This file is part of Markam

;; Markam is free software: you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; Markam is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with Markam. If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; Path-related functions.

;;; Code:

(declare (unit paths))

(define (stored-file xdg-env file #!optional dir)
  ;; Get FILE either from `XDG-ENV/markam/' or from `$HOME/.markam/'.
  ;; Prefer any existing file over any other, but prefer files using
  ;; XDG-ENV over `$HOME'.
  (let* ((xdg (get-environment-variable xdg-env))
         (dir (or dir "markam"))
         (stored-file (string-append (get-environment-variable "HOME") "/." dir "/" file)))
    (unless (or (file-exists? stored-file) (not xdg))
      (set! stored-file (string-append xdg "/" dir "/" file)))
    stored-file))

(define (config-file file)
  ;; Use `stored-file' to get configuration file FILE.  Configuration
  ;; files are stored under `$XDG_CONFIG_HOME' if the XDG standard is
  ;; used.
  (stored-file "XDG_CONFIG_HOME" file))

(define (data-file file #!optional dir)
  ;; Use `stored-file' to get data file FILE. Data files are stored
  ;; under `$XDG_DATA_HOME' if the XDG standard is used.
  (stored-file "XDG_DATA_HOME" file dir))
